==> geant4-v11.3.2.tar.gz: geant4-v11.3.2/source/processes/hadronic/models/inclxx/incl_physics/sources.cmake <==
# - G4hadronic_inclxx_physics module build definition

# Define the Geant4 Module.
geant4_add_module(G4hadronic_inclxx_physics
  PUBLIC_HEADERS
    G4INCLAvatarDumpAction.hh
    G4INCLBinaryCollisionAvatar.hh
    G4INCLCascade.hh
    G4INCLCascadeAction.hh
    G4INCLCDPP.hh
    G4INCLCluster.hh
    G4INCLClusterDecay.hh
    G4INCLClustering.hh
    G4INCLClusteringModelIntercomparison.hh
    G4INCLClusteringModelNone.hh
    G4INCLConstantRandom.hh
    G4INCLCoulombDistortion.hh
    G4INCLCoulombNone.hh
    G4INCLCoulombNonRelativistic.hh
    G4INCLCrossSections.hh
    G4INCLCrossSectionsAntiparticles.hh
    G4INCLCrossSectionsINCL46.hh
    G4INCLCrossSectionsMultiPions.hh
    G4INCLCrossSectionsMultiPionsAndResonances.hh
    G4INCLCrossSectionsStrangeness.hh
    G4INCLCrossSectionsTruncatedMultiPions.hh
    G4INCLDecayAvatar.hh
    G4INCLDeJongSpin.hh
    G4INCLDeltaDecayChannel.hh
    G4INCLDeltaProductionChannel.hh
    G4INCLDeuteronDensity.hh
    G4INCLElasticChannel.hh
    G4INCLEtaNElasticChannel.hh
    G4INCLEtaNToPiNChannel.hh
    G4INCLEtaNToPiPiNChannel.hh
    G4INCLIClusteringModel.hh
    G4INCLICoulomb.hh
    G4INCLICrossSections.hh
    G4INCLInteractionAvatar.hh
    G4INCLINuclearPotential.hh
    G4INCLIPauli.hh
    G4INCLIPhaseSpaceGenerator.hh
    G4INCLIPropagationModel.hh
    G4INCLKinematicsUtils.hh
    G4INCLNDeltaEtaProductionChannel.hh
    G4INCLNDeltaOmegaProductionChannel.hh
    G4INCLNDeltaToDeltaLKChannel.hh
    G4INCLNDeltaToDeltaSKChannel.hh
    G4INCLNDeltaToNLKChannel.hh
    G4INCLNDeltaToNNKKbChannel.hh
    G4INCLNDeltaToNSKChannel.hh
    G4INCLNDFGaussian.hh
    G4INCLNDFHardSphere.hh
    G4INCLNDFModifiedHarmonicOscillator.hh
    G4INCLNDFParis.hh
    G4INCLNDFWoodsSaxon.hh
    G4INCLNeutralKaonDecayChannel.hh
    G4INCLNKbElasticChannel.hh
    G4INCLNKbToL2piChannel.hh
    G4INCLNKbToLpiChannel.hh
    G4INCLNKbToNKb2piChannel.hh
    G4INCLNKbToNKbChannel.hh
    G4INCLNKbToNKbpiChannel.hh
    G4INCLNKbToS2piChannel.hh
    G4INCLNKbToSpiChannel.hh
    G4INCLNKElasticChannel.hh
    G4INCLNKToNK2piChannel.hh
    G4INCLNKToNKChannel.hh
    G4INCLNKToNKpiChannel.hh
    G4INCLNLToNSChannel.hh
    G4INCLNNbarCEXChannel.hh
    G4INCLNNbarElasticChannel.hh
    G4INCLNNbarToLLbarChannel.hh
    G4INCLNNbarToNNbarpiChannel.hh
    G4INCLNNbarToNNbar2piChannel.hh
    G4INCLNNbarToNNbar3piChannel.hh
    G4INCLNNbarToAnnihilationChannel.hh
    G4INCLNNEtaToMultiPionsChannel.hh
    G4INCLNNOmegaToMultiPionsChannel.hh
    G4INCLNNToMissingStrangenessChannel.hh
    G4INCLNNToMultiPionsChannel.hh
    G4INCLNNToNLK2piChannel.hh
    G4INCLNNToNLKChannel.hh
    G4INCLNNToNLKpiChannel.hh
    G4INCLNNToNNEtaChannel.hh
    G4INCLNNToNNKKbChannel.hh
    G4INCLNNToNNOmegaChannel.hh
    G4INCLNNToNSK2piChannel.hh
    G4INCLNNToNSKChannel.hh
    G4INCLNNToNSKpiChannel.hh
    G4INCLNpiToLK2piChannel.hh
    G4INCLNpiToLKChannel.hh
    G4INCLNpiToLKpiChannel.hh
    G4INCLNpiToMissingStrangenessChannel.hh
    G4INCLNpiToNKKbChannel.hh
    G4INCLNpiToSK2piChannel.hh
    G4INCLNpiToSKChannel.hh
    G4INCLNpiToSKpiChannel.hh
    G4INCLNSToNLChannel.hh
    G4INCLNSToNSChannel.hh
    G4INCLNuclearDensity.hh
    G4INCLNuclearDensityFactory.hh
    G4INCLNuclearPotentialConstant.hh
    G4INCLNuclearPotentialEnergyIsospin.hh
    G4INCLNuclearPotentialEnergyIsospinSmooth.hh
    G4INCLNuclearPotentialIsospin.hh
    G4INCLNucleus.hh
    G4INCLNYElasticChannel.hh
    G4INCLOmegaNElasticChannel.hh
    G4INCLOmegaNToPiNChannel.hh
    G4INCLOmegaNToPiPiNChannel.hh
    G4INCLParticleEntryAvatar.hh
    G4INCLParticleEntryChannel.hh
    G4INCLParticleSampler.hh
    G4INCLPauliBlocking.hh
    G4INCLPauliGlobal.hh
    G4INCLPauliStandard.hh
    G4INCLPauliStrict.hh
    G4INCLPauliStrictStandard.hh
    G4INCLPbarAtrestEntryChannel.hh
    G4INCLPhaseSpaceGenerator.hh
    G4INCLPhaseSpaceKopylov.hh
    G4INCLPhaseSpaceRauboldLynch.hh
    G4INCLPiNElasticChannel.hh
    G4INCLPiNToDeltaChannel.hh
    G4INCLPiNToEtaChannel.hh
    G4INCLPiNToMultiPionsChannel.hh
    G4INCLPiNToOmegaChannel.hh
    G4INCLPionResonanceDecayChannel.hh
    G4INCLProjectileRemnant.hh
    G4INCLRecombinationChannel.hh
    G4INCLReflectionChannel.hh
    G4INCLSigmaZeroDecayChannel.hh
    G4INCLStandardPropagationModel.hh
    G4INCLStore.hh
    G4INCLStrangeAbsorbtionChannel.hh
    G4INCLSurfaceAvatar.hh
    G4INCLTransmissionChannel.hh
  SOURCES
    G4INCLAvatarDumpAction.cc
    G4INCLBinaryCollisionAvatar.cc
    G4INCLCascade.cc
    G4INCLCascadeAction.cc
    G4INCLCDPP.cc
    G4INCLCluster.cc
    G4INCLClusterDecay.cc
    G4INCLClustering.cc
    G4INCLClusteringModelIntercomparison.cc
    G4INCLCoulombDistortion.cc
    G4INCLCoulombNone.cc
    G4INCLCoulombNonRelativistic.cc
    G4INCLCrossSections.cc
    G4INCLCrossSectionsAntiparticles.cc
    G4INCLCrossSectionsINCL46.cc
    G4INCLCrossSectionsMultiPions.cc
    G4INCLCrossSectionsMultiPionsAndResonances.cc
    G4INCLCrossSectionsStrangeness.cc
    G4INCLCrossSectionsTruncatedMultiPions.cc
    G4INCLDecayAvatar.cc
    G4INCLDeJongSpin.cc
    G4INCLDeltaDecayChannel.cc
    G4INCLDeltaProductionChannel.cc
    G4INCLDeuteronDensity.cc
    G4INCLElasticChannel.cc
    G4INCLEtaNElasticChannel.cc
    G4INCLEtaNToPiNChannel.cc
    G4INCLEtaNToPiPiNChannel.cc
    G4INCLInteractionAvatar.cc
    G4INCLINuclearPotential.cc
    G4INCLKinematicsUtils.cc
    G4INCLNDeltaEtaProductionChannel.cc
    G4INCLNDeltaOmegaProductionChannel.cc
    G4INCLNDeltaToDeltaLKChannel.cc
    G4INCLNDeltaToDeltaSKChannel.cc
    G4INCLNDeltaToNLKChannel.cc
    G4INCLNDeltaToNNKKbChannel.cc
    G4INCLNDeltaToNSKChannel.cc
    G4INCLNeutralKaonDecayChannel.cc
    G4INCLNKbElasticChannel.cc
    G4INCLNKbToL2piChannel.cc
    G4INCLNKbToLpiChannel.cc
    G4INCLNKbToNKb2piChannel.cc
    G4INCLNKbToNKbChannel.cc
    G4INCLNKbToNKbpiChannel.cc
    G4INCLNKbToS2piChannel.cc
    G4INCLNKbToSpiChannel.cc
    G4INCLNKElasticChannel.cc
    G4INCLNKToNK2piChannel.cc
    G4INCLNKToNKChannel.cc
    G4INCLNKToNKpiChannel.cc
    G4INCLNLToNSChannel.cc
    G4INCLNNbarCEXChannel.cc
    G4INCLNNbarElasticChannel.cc
    G4INCLNNbarToLLbarChannel.cc
    G4INCLNNbarToNNbarpiChannel.cc
    G4INCLNNbarToNNbar2piChannel.cc
    G4INCLNNbarToNNbar3piChannel.cc
    G4INCLNNbarToAnnihilationChannel.cc
    G4INCLNNEtaToMultiPionsChannel.cc
    G4INCLNNOmegaToMultiPionsChannel.cc
    G4INCLNNToMissingStrangenessChannel.cc
    G4INCLNNToMultiPionsChannel.cc
    G4INCLNNToNLK2piChannel.cc
    G4INCLNNToNLKChannel.cc
    G4INCLNNToNLKpiChannel.cc
    G4INCLNNToNNEtaChannel.cc
    G4INCLNNToNNKKbChannel.cc
    G4INCLNNToNNOmegaChannel.cc
    G4INCLNNToNSK2piChannel.cc
    G4INCLNNToNSKChannel.cc
    G4INCLNNToNSKpiChannel.cc
    G4INCLNpiToLK2piChannel.cc
    G4INCLNpiToLKChannel.cc
    G4INCLNpiToLKpiChannel.cc
    G4INCLNpiToMissingStrangenessChannel.cc
    G4INCLNpiToNKKbChannel.cc
    G4INCLNpiToSK2piChannel.cc
    G4INCLNpiToSKChannel.cc
    G4INCLNpiToSKpiChannel.cc
    G4INCLNSToNLChannel.cc
    G4INCLNSToNSChannel.cc
    G4INCLNuclearDensity.cc
    G4INCLNuclearDensityFactory.cc
    G4INCLNuclearPotentialConstant.cc
    G4INCLNuclearPotentialEnergyIsospin.cc
    G4INCLNuclearPotentialEnergyIsospinSmooth.cc
    G4INCLNuclearPotentialIsospin.cc
    G4INCLNucleus.cc
    G4INCLNYElasticChannel.cc
    G4INCLOmegaNElasticChannel.cc
    G4INCLOmegaNToPiNChannel.cc
    G4INCLOmegaNToPiPiNChannel.cc
    G4INCLParticleEntryAvatar.cc
    G4INCLParticleEntryChannel.cc
    G4INCLParticleSampler.cc
    G4INCLPauliBlocking.cc
    G4INCLPauliGlobal.cc
    G4INCLPauliStandard.cc
    G4INCLPauliStrict.cc
    G4INCLPauliStrictStandard.cc
    G4INCLPbarAtrestEntryChannel.cc
    G4INCLPhaseSpaceGenerator.cc
    G4INCLPhaseSpaceKopylov.cc
    G4INCLPhaseSpaceRauboldLynch.cc
    G4INCLPiNElasticChannel.cc
    G4INCLPiNToDeltaChannel.cc
    G4INCLPiNToEtaChannel.cc
    G4INCLPiNToMultiPionsChannel.cc
    G4INCLPiNToOmegaChannel.cc
    G4INCLPionResonanceDecayChannel.cc
    G4INCLProjectileRemnant.cc
    G4INCLRecombinationChannel.cc
    G4INCLReflectionChannel.cc
    G4INCLSigmaZeroDecayChannel.cc
    G4INCLStandardPropagationModel.cc
    G4INCLStore.cc
    G4INCLStrangeAbsorbtionChannel.cc
    G4INCLSurfaceAvatar.cc
    G4INCLTransmissionChannel.cc)

geant4_module_link_libraries(G4hadronic_inclxx_physics
  PUBLIC
    G4globman
    G4hadronic_inclxx_utils)

==> geant4-v11.4.0.tar.gz: geant4-v11.4.0/source/processes/hadronic/models/inclxx/incl_physics/sources.cmake <==
# - G4hadronic_inclxx_physics module build definition

# Define the Geant4 Module.
geant4_add_module(G4hadronic_inclxx_physics
  PUBLIC_HEADERS
    G4INCLAntinucleiAtrestEntryChannel.hh
    G4INCLAvatarDumpAction.hh
    G4INCLBinaryCollisionAvatar.hh
    G4INCLCascade.hh
    G4INCLCascadeAction.hh
    G4INCLCDPP.hh
    G4INCLCluster.hh
    G4INCLClusterDecay.hh
    G4INCLClustering.hh
    G4INCLClusteringModelIntercomparison.hh
    G4INCLClusteringModelNone.hh
    G4INCLConstantRandom.hh
    G4INCLCoulombDistortion.hh
    G4INCLCoulombNone.hh
    G4INCLCoulombNonRelativistic.hh
    G4INCLCrossSections.hh
    G4INCLCrossSectionsAntiparticles.hh
    G4INCLCrossSectionsINCL46.hh
    G4INCLCrossSectionsMultiPions.hh
    G4INCLCrossSectionsMultiPionsAndResonances.hh
    G4INCLCrossSectionsStrangeness.hh
    G4INCLCrossSectionsTruncatedMultiPions.hh
    G4INCLDecayAvatar.hh
    G4INCLDeJongSpin.hh
    G4INCLDeltaDecayChannel.hh
    G4INCLDeltaProductionChannel.hh
    G4INCLDeuteronDensity.hh
    G4INCLElasticChannel.hh
    G4INCLEtaNElasticChannel.hh
    G4INCLEtaNToPiNChannel.hh
    G4INCLEtaNToPiPiNChannel.hh
    G4INCLEtaOrOmegaNToLKChannel.hh
    G4INCLEtaOrOmegaNToSKChannel.hh
    G4INCLIClusteringModel.hh
    G4INCLICoulomb.hh
    G4INCLICrossSections.hh
    G4INCLInteractionAvatar.hh
    G4INCLINuclearPotential.hh
    G4INCLIPauli.hh
    G4INCLIPhaseSpaceGenerator.hh
    G4INCLIPropagationModel.hh
    G4INCLKinematicsUtils.hh
    G4INCLNbarAtrestEntryChannel.hh
    G4INCLNDeltaEtaProductionChannel.hh
    G4INCLNDeltaOmegaProductionChannel.hh
    G4INCLNDeltaToDeltaLKChannel.hh
    G4INCLNDeltaToDeltaSKChannel.hh
    G4INCLNDeltaToNLKChannel.hh
    G4INCLNDeltaToNNKKbChannel.hh
    G4INCLNDeltaToNSKChannel.hh
    G4INCLNDFGaussian.hh
    G4INCLNDFHardSphere.hh
    G4INCLNDFModifiedHarmonicOscillator.hh
    G4INCLNDFParis.hh
    G4INCLNDFWoodsSaxon.hh
    G4INCLNeutralKaonDecayChannel.hh
    G4INCLNKbElasticChannel.hh
    G4INCLNKbToL2piChannel.hh
    G4INCLNKbToLpiChannel.hh
    G4INCLNKbToNKb2piChannel.hh
    G4INCLNKbToNKbChannel.hh
    G4INCLNKbToNKbpiChannel.hh
    G4INCLNKbToS2piChannel.hh
    G4INCLNKbToSpiChannel.hh
    G4INCLNKElasticChannel.hh
    G4INCLNKToNK2piChannel.hh
    G4INCLNKToNKChannel.hh
    G4INCLNKToNKpiChannel.hh
    G4INCLNLToNSChannel.hh
    G4INCLNNbarCEXChannel.hh
    G4INCLNNbarElasticChannel.hh
    G4INCLNNbarToLLbarChannel.hh
    G4INCLNNbarToNNbarpiChannel.hh
    G4INCLNNbarToNNbar2piChannel.hh
    G4INCLNNbarToNNbar3piChannel.hh
    G4INCLNNbarToAnnihilationChannel.hh
    G4INCLNNEtaToMultiPionsChannel.hh
    G4INCLNNOmegaToMultiPionsChannel.hh
    G4INCLNNToMissingStrangenessChannel.hh
    G4INCLNNToMultiPionsChannel.hh
    G4INCLNNToNLK2piChannel.hh
    G4INCLNNToNLKChannel.hh
    G4INCLNNToNLKpiChannel.hh
    G4INCLNNToNNEtaChannel.hh
    G4INCLNNToNNKKbChannel.hh
    G4INCLNNToNNOmegaChannel.hh
    G4INCLNNToNSK2piChannel.hh
    G4INCLNNToNSKChannel.hh
    G4INCLNNToNSKpiChannel.hh
    G4INCLNpiToLK2piChannel.hh
    G4INCLNpiToLKChannel.hh
    G4INCLNpiToLKpiChannel.hh
    G4INCLNpiToMissingStrangenessChannel.hh
    G4INCLNpiToNKKbChannel.hh
    G4INCLNpiToSK2piChannel.hh
    G4INCLNpiToSKChannel.hh
    G4INCLNpiToSKpiChannel.hh
    G4INCLNSToNLChannel.hh
    G4INCLNSToNSChannel.hh
    G4INCLNuclearDensity.hh
    G4INCLNuclearDensityFactory.hh
    G4INCLNuclearPotentialConstant.hh
    G4INCLNuclearPotentialEnergyIsospin.hh
    G4INCLNuclearPotentialEnergyIsospinSmooth.hh
    G4INCLNuclearPotentialIsospin.hh
    G4INCLNucleus.hh
    G4INCLNYElasticChannel.hh
    G4INCLOmegaNElasticChannel.hh
    G4INCLOmegaNToPiNChannel.hh
    G4INCLOmegaNToPiPiNChannel.hh
    G4INCLParticleEntryAvatar.hh
    G4INCLParticleEntryChannel.hh
    G4INCLParticleSampler.hh
    G4INCLPauliBlocking.hh
    G4INCLPauliGlobal.hh
    G4INCLPauliStandard.hh
    G4INCLPauliStrict.hh
    G4INCLPauliStrictStandard.hh
    G4INCLPbarAtrestEntryChannel.hh
    G4INCLPhaseSpaceGenerator.hh
    G4INCLPhaseSpaceKopylov.hh
    G4INCLPhaseSpaceRauboldLynch.hh
    G4INCLPiNElasticChannel.hh
    G4INCLPiNToDeltaChannel.hh
    G4INCLPiNToEtaChannel.hh
    G4INCLPiNToMultiPionsChannel.hh
    G4INCLPiNToOmegaChannel.hh
    G4INCLPionResonanceDecayChannel.hh
    G4INCLProjectileRemnant.hh
    G4INCLRecombinationChannel.hh
    G4INCLReflectionChannel.hh
    G4INCLSigmaZeroDecayChannel.hh
    G4INCLSrcChannel.hh
    G4INCLStandardPropagationModel.hh
    G4INCLStore.hh
    G4INCLStrangeAbsorbtionChannel.hh
    G4INCLSurfaceAvatar.hh
    G4INCLTransmissionChannel.hh
  SOURCES
    G4INCLAntinucleiAtrestEntryChannel.cc  
    G4INCLAvatarDumpAction.cc
    G4INCLBinaryCollisionAvatar.cc
    G4INCLCascade.cc
    G4INCLCascadeAction.cc
    G4INCLCDPP.cc
    G4INCLCluster.cc
    G4INCLClusterDecay.cc
    G4INCLClustering.cc
    G4INCLClusteringModelIntercomparison.cc
    G4INCLCoulombDistortion.cc
    G4INCLCoulombNone.cc
    G4INCLCoulombNonRelativistic.cc
    G4INCLCrossSections.cc
    G4INCLCrossSectionsAntiparticles.cc
    G4INCLCrossSectionsINCL46.cc
    G4INCLCrossSectionsMultiPions.cc
    G4INCLCrossSectionsMultiPionsAndResonances.cc
    G4INCLCrossSectionsStrangeness.cc
    G4INCLCrossSectionsTruncatedMultiPions.cc
    G4INCLDecayAvatar.cc
    G4INCLDeJongSpin.cc
    G4INCLDeltaDecayChannel.cc
    G4INCLDeltaProductionChannel.cc
    G4INCLDeuteronDensity.cc
    G4INCLElasticChannel.cc
    G4INCLEtaNElasticChannel.cc
    G4INCLEtaNToPiNChannel.cc
    G4INCLEtaNToPiPiNChannel.cc
    G4INCLEtaOrOmegaNToLKChannel.cc
    G4INCLEtaOrOmegaNToSKChannel.cc
    G4INCLInteractionAvatar.cc
    G4INCLINuclearPotential.cc
    G4INCLKinematicsUtils.cc
    G4INCLNbarAtrestEntryChannel.cc
    G4INCLNDeltaEtaProductionChannel.cc
    G4INCLNDeltaOmegaProductionChannel.cc
    G4INCLNDeltaToDeltaLKChannel.cc
    G4INCLNDeltaToDeltaSKChannel.cc
    G4INCLNDeltaToNLKChannel.cc
    G4INCLNDeltaToNNKKbChannel.cc
    G4INCLNDeltaToNSKChannel.cc
    G4INCLNeutralKaonDecayChannel.cc
    G4INCLNKbElasticChannel.cc
    G4INCLNKbToL2piChannel.cc
    G4INCLNKbToLpiChannel.cc
    G4INCLNKbToNKb2piChannel.cc
    G4INCLNKbToNKbChannel.cc
    G4INCLNKbToNKbpiChannel.cc
    G4INCLNKbToS2piChannel.cc
    G4INCLNKbToSpiChannel.cc
    G4INCLNKElasticChannel.cc
    G4INCLNKToNK2piChannel.cc
    G4INCLNKToNKChannel.cc
    G4INCLNKToNKpiChannel.cc
    G4INCLNLToNSChannel.cc
    G4INCLNNbarCEXChannel.cc
    G4INCLNNbarElasticChannel.cc
    G4INCLNNbarToLLbarChannel.cc
    G4INCLNNbarToNNbarpiChannel.cc
    G4INCLNNbarToNNbar2piChannel.cc
    G4INCLNNbarToNNbar3piChannel.cc
    G4INCLNNbarToAnnihilationChannel.cc
    G4INCLNNEtaToMultiPionsChannel.cc
    G4INCLNNOmegaToMultiPionsChannel.cc
    G4INCLNNToMissingStrangenessChannel.cc
    G4INCLNNToMultiPionsChannel.cc
    G4INCLNNToNLK2piChannel.cc
    G4INCLNNToNLKChannel.cc
    G4INCLNNToNLKpiChannel.cc
    G4INCLNNToNNEtaChannel.cc
    G4INCLNNToNNKKbChannel.cc
    G4INCLNNToNNOmegaChannel.cc
    G4INCLNNToNSK2piChannel.cc
    G4INCLNNToNSKChannel.cc
    G4INCLNNToNSKpiChannel.cc
    G4INCLNpiToLK2piChannel.cc
    G4INCLNpiToLKChannel.cc
    G4INCLNpiToLKpiChannel.cc
    G4INCLNpiToMissingStrangenessChannel.cc
    G4INCLNpiToNKKbChannel.cc
    G4INCLNpiToSK2piChannel.cc
    G4INCLNpiToSKChannel.cc
    G4INCLNpiToSKpiChannel.cc
    G4INCLNSToNLChannel.cc
    G4INCLNSToNSChannel.cc
    G4INCLNuclearDensity.cc
    G4INCLNuclearDensityFactory.cc
    G4INCLNuclearPotentialConstant.cc
    G4INCLNuclearPotentialEnergyIsospin.cc
    G4INCLNuclearPotentialEnergyIsospinSmooth.cc
    G4INCLNuclearPotentialIsospin.cc
    G4INCLNucleus.cc
    G4INCLNYElasticChannel.cc
    G4INCLOmegaNElasticChannel.cc
    G4INCLOmegaNToPiNChannel.cc
    G4INCLOmegaNToPiPiNChannel.cc
    G4INCLParticleEntryAvatar.cc
    G4INCLParticleEntryChannel.cc
    G4INCLParticleSampler.cc
    G4INCLPauliBlocking.cc
    G4INCLPauliGlobal.cc
    G4INCLPauliStandard.cc
    G4INCLPauliStrict.cc
    G4INCLPauliStrictStandard.cc
    G4INCLPbarAtrestEntryChannel.cc
    G4INCLPhaseSpaceGenerator.cc
    G4INCLPhaseSpaceKopylov.cc
    G4INCLPhaseSpaceRauboldLynch.cc
    G4INCLPiNElasticChannel.cc
    G4INCLPiNToDeltaChannel.cc
    G4INCLPiNToEtaChannel.cc
    G4INCLPiNToMultiPionsChannel.cc
    G4INCLPiNToOmegaChannel.cc
    G4INCLPionResonanceDecayChannel.cc
    G4INCLProjectileRemnant.cc
    G4INCLRecombinationChannel.cc
    G4INCLReflectionChannel.cc
    G4INCLSigmaZeroDecayChannel.cc
    G4INCLSrcChannel.cc
    G4INCLStandardPropagationModel.cc
    G4INCLStore.cc
    G4INCLStrangeAbsorbtionChannel.cc
    G4INCLSurfaceAvatar.cc
    G4INCLTransmissionChannel.cc)

geant4_module_link_libraries(G4hadronic_inclxx_physics
  PUBLIC
    G4globman
    G4hadronic_inclxx_utils)
